@@ -1,23 +1,29 @@
 # Import libraries
 from moesifapi.moesif_api_client import APIHelper
 from datetime import datetime
-
+from urllib.parse import urlparse
 
 class UtilityFunction():
     # Function to get the current time
     def get_current_time(self):
         return datetime.utcnow().strftime("%Y-%m-%dT%H:%M:%S.%f")[:-3]
 
+    # Function to check if the allowed url is valid
+    @classmethod
+    def is_valid_url(cls, url):
+        try:
+            parsed_url = urlparse(url)
+            return parsed_url.netloc.endswith('.moesif.net')
+        except:
+            return False
+
     # Function to check if the event is to Moesif
     def is_moesif(self, request_headers, url):
         if request_headers and isinstance(request_headers, dict):
             if request_headers.get('X-Moesif-SDK', None) is not None or request_headers.get('X-Moesif-Application-Id', None) is not None:
                 return True
 
-        if url and 'moesif.net' in url:
-            return True
-
-        return False
+        return self.is_valid_url(url)
 
     # Function to mask the body
     def mask_body(self, body, masks):
@@ -51,16 +57,11 @@ class UtilityFunction():
             return ''
         return APIHelper.json_serialize(value)
 
-    # Function to transform the request headers
-    def transform_key(self, key):
-        key = key.upper()
-        key = key.replace('-', '_')
-        return key
 
     # Function to create request headers
     def create_request_headers(self, req_headers):
         try:
-            req_headers = {self.transform_key(k): v for k, v in req_headers.items()}
+            req_headers = {k: v for k, v in req_headers.items()}
         except:
             req_headers = {}
         return req_headers
